package com.ruoyi.workflow.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.workflow.domain.UserDeployRelation;
import com.ruoyi.workflow.domain.bo.UserDeployRelationBo;
import com.ruoyi.workflow.domain.vo.UserDeployRelationVo;
import com.ruoyi.workflow.mapper.UserDeployRelationMapper;
import com.ruoyi.workflow.service.IUserDeployRelationService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 用户流程关联Service业务层处理
 *
 * @author ruoyi
 * @date 2024-04-25
 */
@RequiredArgsConstructor
@Service
public class UserDeployRelationServiceImpl implements IUserDeployRelationService {

    private final UserDeployRelationMapper baseMapper;

    /**
     * 查询用户流程关联
     */
    @Override
    public UserDeployRelationVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询用户流程关联列表
     */
    @Override
    public TableDataInfo<UserDeployRelationVo> queryPageList(UserDeployRelationBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<UserDeployRelation> lqw = buildQueryWrapper(bo);
        Page<UserDeployRelationVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询用户流程关联列表
     */
    @Override
    public List<UserDeployRelationVo> queryList(UserDeployRelationBo bo) {
        LambdaQueryWrapper<UserDeployRelation> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<UserDeployRelation> buildQueryWrapper(UserDeployRelationBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<UserDeployRelation> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getCellphone()), UserDeployRelation::getCellphone, bo.getCellphone());
        lqw.eq(StringUtils.isNotBlank(bo.getDeployId()), UserDeployRelation::getDeployId, bo.getDeployId());
        return lqw;
    }

    /**
     * 新增用户流程关联
     */
    @Override
    public Boolean insertByBo(UserDeployRelationBo bo) {
        UserDeployRelation add = BeanUtil.toBean(bo, UserDeployRelation.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改用户流程关联
     */
    @Override
    public Boolean updateByBo(UserDeployRelationBo bo) {
        UserDeployRelation update = BeanUtil.toBean(bo, UserDeployRelation.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(UserDeployRelation entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除用户流程关联
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
